
data {
  int<lower=1> K;          // number of mixture components
  int<lower=1> N;          // number of data points
  real y[N];               // observations
  real sigma;
}

parameters {
  simplex[K] theta;          // mixing proportions
  ordered[K] mu;             // locations of mixture components
}

model {
  vector[K] contributions;
  theta ~ dirichlet(rep_vector(1., K));
  for (i in 1:K) {
    mu[i] ~ normal(0, 5);
  }
  
  // likelihood
  for (i in 1:N) {
    for (k in 1:K) {
      contributions[k] = log(theta[k]) + normal_lpdf(y[i] | mu[k], sigma);
    }
    target += log_sum_exp(contributions);
  }
}
